#!/bin/sh
#
# SiteManager Embedded for Linux
# Installer script
#
# (c) Copyright 2014-2019 Secomea A/S, Denmark.  All rights reserved
#

if [ "`id -u`" -ne 0 ] ; then
    echo "Please install SiteManager as root (use su or sudo)."
    exit 1
fi

[ -f sitemanager.rc ] || exit 1

YES=false
START=true
INSTDIR=
CFGFILE=
MORE=

while [ -n "$1" ] ; do
    case "x$1" in
	x-y)
	    YES=true
	    MORE=cat
	    ;;
	x-n)
	    START=false
	    ;;
	x-d)
	    shift
	    if [ -n "$1" ] ; then
		INSTDIR="$1"
	    fi
	    ;;
	x-c)
	    shift
	    if [ -n "$1" ] ; then
		CFGFILE="$1"
	    fi
	    ;;
	*)
	    echo "Ignore option: $1"
	    ;;
    esac
    shift
done

if [ -z "$MORE" ] ; then
    MORE=cat
    if more /dev/null </dev/null; then MORE=more ; fi >/dev/null 2>/dev/null
fi

(
echo "+----------------------------------------------------------------------"
echo "|"
sed -e 's/^/| /' -e '/INSTALLATION/,$d' README
echo "|"
echo "| *** BY CONTINUING WITH THE INSTALLATION, YOU ACCEPT THESE TERMS. ***"
echo "|"
echo "+----------------------------------------------------------------------"
) | $MORE

echo
echo -n "Accept terms and continue with installation (yes,no) [no] "
if $YES ; then
   echo YES
   OK=Y
else
    read OK
fi

case "${OK}" in
    [Yy]*) ;;
    *) echo "Installation cancelled." ;	exit 0 ;;
esac

SOURCE=
for arch in  x64 x86 ; do
  if [ -z "${SOURCE}" ] ; then
    if ${arch}/sitemanager -v ; then
      SOURCE=${arch}
    fi
  fi
done >/dev/null 2>/dev/null

if [ -z "${SOURCE}" ] ; then
    echo "SiteManager executable not compatible with this platform."
    exit 9
fi

RCSCRIPT=/etc/init.d/sitemanager

if [ -z "$INSTDIR" -a -f $RCSCRIPT ] ; then
    SMDIR=
    grep '^SMDIR=' $RCSCRIPT > _INSTDIR
    . ./_INSTDIR
    rm -f _INSTDIR
    INSTDIR="$SMDIR"
fi

if [ -z "$INSTDIR" ] ; then
    INSTDIR=/usr/local/sitemanager
fi

if $YES ; then
    echo "Installation directory: $INSTDIR"
    SMDIR="$INSTDIR"
else
    echo -n "Enter installation directory: [$INSTDIR] "
    read SMDIR
    if [ -z "$SMDIR" ] ; then
	SMDIR="$INSTDIR"
    fi
fi

[ -d "$SMDIR" ] || mkdir -p "$SMDIR" || exit 1

CFGDIR=/etc/sitemanager
CFG=${CFGDIR}/sme.txt
SM="${SMDIR}/sitemanager"
SOURCEDIR=./${SOURCE}


if [ -f $RCSCRIPT ] ; then
   [ -d "$SMDIR" -a -f "$SMDIR/sitemanager" ] && "$RCSCRIPT" stop quiet
fi
if [ -d "${CFGDIR}" ] && [ -f $SM ]; then
   $SM -KILL
fi

cat<<EOF


==============================================================

EOF
echo -n "Installing "
./${SOURCE}/sitemanager -v

cat<<EOF

==============================================================

EOF

cp $SOURCEDIR/* "$SMDIR"
(
    cd "$SMDIR"
    chown root.root . *
    chmod -f 6755 sitemanager dcm_*
    chmod -f 644 lib*.so*
)

echo "Installed $SMDIR ($SOURCE) files."

if [ -d /etc/init.d ] ; then
    sed -e "s:__DIR__:$SMDIR:" sitemanager.rc > $RCSCRIPT
    if [ -f $RCSCRIPT ] ; then
	chmod 755 $RCSCRIPT
	if which chkconfig > /dev/null 2>&1 ; then
	    chkconfig --add sitemanager
	else
	    for L in 0 1 6 ; do
		ln -f -s ../init.d/sitemanager /etc/rc$L.d/K01sitemanager
	    done
	    for L in 2 3 4 5 ; do
		ln -f -s ../init.d/sitemanager /etc/rc$L.d/S99sitemanager
	    done
	fi
    fi
    echo "Installed $RCSCRIPT script."
elif grep sitemanager /etc/rc.local ; then
    echo > /dev/null
else
    echo "# Start SiteManager Embedded" >> /etc/rc.local
    echo "$SM start" >> /etc/rc.local
fi

if [ -n "$CFGFILE" -a -e "$CFGFILE" ] ; then
    mkdir -p $CFGDIR
    cp -f "$CFGFILE" "$CFG"
fi

if [ ! -f $CFG ] ; then
    echo
    echo "Create SiteManager configuration (hit Enter to configure later):"
    echo

    echo -n "GateManager Server (Hostname or IP): "
    read GMHOST

    if [ -n "$GMHOST" ] ; then
	echo -n "GateManager Token: "
	read GMTOKEN
	echo -n "SiteManager Name: "
	read SMNAME

	mkdir -p $CFGDIR
	echo "Server=$GMHOST" > $CFG
	[ -n "$GMTOKEN" ] && echo "Domain=$GMTOKEN" >> $CFG
	[ -n "$SMNAME" ] && echo "Name=$SMNAME" >> $CFG
    fi
fi

if $START && [ -f $CFG ] ; then
    echo
    echo -n "Start SiteManager Service now (yn)? [yes] "
    if $YES ; then
	echo YES
	START=Y
    else
	read START
    fi

    case "${START}Y" in
	[Yy]*)
	    if [ -f $RCSCRIPT ] ; then
		$RCSCRIPT start
	    else
		"$SM" start
	    fi
	    ;;
    esac
fi

cat<<EOF

==============================================================

Installation complete.

You can configure SiteManager via the following URL:
   http://127.0.0.1:11444

==============================================================

EOF
